## So you want to do a PhD?

I enthusiastically welcome applications to undertake PhD study in our department at the University of Birmingham. I should also note that applications by minoritised scholars and in programmes of research pursuing subjects and following critical frames of reference which are relevant to non privileged contexts are particularly welcome (e.g. post-colonial, black theology, feminist, eco-womanist, liberation, queer theology, etc.). 

The process of application varies from country to country, in some cases dramatically, so I have written this brief guide so that anyone wanting to apply will have a fair sense of the criteria and expectations for application.

## Features of the UK PhD

First a few salient details about our context here (in the UK at large research-intensive Universities):

- A British PhD is generally expected to take 3 years, with an additional fourth or (in rare cases) fifth year to write-up a final draft of your work. In spite of how that sounds, this is a rather brief window of time, particularly in contrast to the USA where PhD students are expected to engage in further generalist preparatory coursework for 1-3 years before taking some sort of comprehensive examination which can validate that they have sufficient general knowledge of the discipline and research methods to conduct research at a doctoral level, leading to a programme of research that can take 5 years or more. Given that this is the case, students will be expected to have completed a strong masters degree *in the subject* they are applying to. If you do not have any previous degrees in religious studies or theology, regardless of how smart you seem to be, I will probably invite you to apply first to complete a 1 year Masters by Research degree under my supervision, ideally exploring some aspect of your preferred research topic or something directly adjacent to it. No matter how many other degrees you have and how well you've done in them (and I include doctorate degrees in other subject areas) this will likely be my suggestion. In some (admittedly rare) cases, progress completed under an MA can be folded into a PhD, so that the candidate generally still completes in 3 years, with two degrees in hand at the end. My experience has shown that there is no substitute for discipline specific background knowledge and research experience and it is a disservice to expect a PhD candidate to cram all that extra work into what is already an accelerated programme.
- Funding for doctoral studies here is rare, with often a maximum of a few partial tuition scholarships awarded in a department each year. Most PhD funding comes from external sources and applications to these are usually driven by the PhD candidate themself. Unless your programme of work is very exceptional: being linked to specific forms of impact (e.g. changing something in the world in a positive and measurable way, with meaningful partnerships and collaborations already in place), or commending dissemination at a high level (e.g. you have already published some forms of scholarly work in highly regarded journals or a scholarly monograph with a reputable press) it is unlikely you will be able to secure funding for your PhD. You should expect to have some form of external funding secured which can support your work (e.g. savings, income support, or paid work). I am a very enthusiastic champion for my students and will write references to support an infinite number of applications for funding should you be proactive enough to pursue it before and during your programme of research. But I think it's important to be clear-eyed in terms of the prospects for securing funding before you have completed a PhD, lest someone come under false pretenses and find themselves unable to complete.
- Cohort size is much less limited here, so that in contrast to the USA, where many supervisors complain that their departments prevent them from supervising more than one or two students at a time, in some cases a supervisor can have more than a dozen students they are working with at any given time. Universities provide us with a workload allocation commensurate with the number of PhD candidates we're supervising and major funders have begun to place limitations at a maximum of 8 FT PhD students under a given scholar's supervision, so there are some protections in place to ensure that each candidate gets due attention during their programme, but I have also found that there is a natural limit that varies from person to person. I generally will only take on a maximum of 6 candidates at any one time. This means that I may be reluctant to take on new PhDs in a particular year, but I'm very happy to keep up correspondence and work with students to refine their proposals in the intervening period such that they can matriculate in the following year (or as soon as some member of my current cohort completes).
- Given the short duration of the programme, PhD candidates undertaking work here are expected to work with a high level of independence. Even in the most colleagial and convivial departments, you will spend a great deal of time working alone, so this is something to bear in mind as you consider undertaking PhD study.
- I meet with my PhD students on a monthly basis, 10 times a year (it is important to take breaks!). I generally expect that you will have written or revised a substantial piece of work for 4-5 of those meetings, and at least one of them will be conducted in the form of a group "laboratory" which will be a group supervision.
- Given all the limits noted above, I invest my energy in "levelling the playing field" for PhD candidates with anxiety, depression, other mental health struggles or who are neurodivergent. I am happy to chat more about this if you have specific questions about how you can successfully complete a PhD if any of these are factors for you (short answer: you can!). I've supported and worked closely with students who are autistic and ADHD and who have been diagnosed with conditions including OCD, bi-polar disorder, anxiety and low mood, and am one of the chairs of our neurodivergent staff network at the UOB. I've also worked closely with researchers who are from a working class background or the first in their family to complete an advanced degree. I see all of these factors and experiences as a form of lived wisdom and not disadvantage, and am very passionate about confronting inequality and crafting better policy to support students in their research.
- You can matriculate for a PhD that is by "distance," e.g. you stay in your home country and we do supervision via videoconference on the same basis outlined above. I generally will expect you to have a good reason as to why remaining in your context will be an integral part of your research process and won't instead be a distraction. To be clear, I'm very aware of the ways that a distance PhD can also reduce inequalities in access to higher education and support practitioners. I've also worked with a number of people in this context so I will be forthright about the challenges we will need to confront together for you to be successful on your research journey if this is part of the landscape for you.
- You can also matriculate for a PhD that is part time, e.g. 5 supervisions a year on a bi-monthly basis over the course of 6-8 years. It's also worth emphasising that the part time PhD will require you to consistently invest 18-20 hours of work per week throughout the year for up to 8 years. I have found in working to support other PhD students that this level of time cannot be stacked up with full time work or caring for the whole period of study without serious impacts on physical and mental health. So, I will expect us to have a conversation about the specific reason why remaining part time is important to your PhD. Needing to work to support yourself or yourself and family is a very good reason, but we'll also need to talk about how your PhD study won't jeopardise your financial security. The long arc of an 8 year project – regardless of the amount of time invested each week - is a major undertaking and carries with it serious stressors which you'll need to plan to mitigate. This will require a certain kind of support network and meaningful solidarity from friends, work, and family. I do not mean to discourage anyone from applying to our programme in this way, but because I am seriously invested in your success as a researcher, I will insist on discussing these matters of self-care, pacing, work intensity and support.
- Generally, the first 6-9 months of your PhD will be some blend of exploratory and constructive inquiry. By the summer of your first year you will need to have written a very polished long-form piece of original research as a writing sample (8k words or so) and an outline of your proposed PhD thesis which will be submitted for a progress panel conducted by my colleagues. If your work is deemed insufficient, this panel can downgrade your degree to an MA or result in the termination of your programme of study, so this is an important milestone. If your project has an empirical or field work component, Y1 will be the time in which you write and complete your application for ethical review, which will, in turn require you to work out a fairly developed account of what you plan to do in your data collection (e.g. participant information sheets, interview questions, recruitment processes). I advise researchers I supervise to conduct scoping work, e.g. forms of data collection that are meant to test your approach and instrument but for which the data won't be used in your final write-up. Finally, you'll likely need to conduct recruitment of respondents and planning such that you can hit the ground running in Y2.
- In the second year, I expect most candidates to work on framing up chapters for their thesis and working on professional development (presenting at conferences, doing book reviews, networking, etc.). If your project has an empirical or field work component, Y2 will be the time when you conduct interviews, surveys, focus groups, etc., complete transcription, and begin initial exploratory analysis, possibly involving a coding process.
- In the third year, you will be working to complete a final polished draft of your thesis, ideally for submission towards a viva voce examination by the end of Y3. 
- The University of Birmingham does not provide any workload allocation for supervision beyond the third year, so whilst I will expect us to correspond and be in regular contact for the fourth year (if you have one), I am not able to provide regular supervisions and will need to book out time for reading drafts carefully, potentially avoiding periods which involve intensive teaching.
- Finally it's worth emphasising that a PhD is a major undertaking and will truly take your full-time attention for three years. I know everyone has side-interests and various distractions, but it will be up to you to ensure that you have time available for regular meetings and are able to put in regular work reading, writing, and reflecting every week, most of the year.

If you stil think you want to apply, read on!

## Now about the process:

### Step 1. Do reconaissance

- Whilst your formal application is to the University and is processed by administrative staff, you should identify one or two specific full-time permanent members of academic staff (i.e. "scholars") you want to do PhD study with. You can find out information about us on our [department websites](https://www.birmingham.ac.uk/staff/profiles/tr/kidwell-jeremy.aspx) or [personal web pages](https://jeremykidwell.info).
- Once you have identified individuals who have conducted research in the specicic area you want to work in (e.g. Christian eco-theology, activist ethnography, phenomenology of time, theology & economics, to list a few of mine), you should **begin preparation** so that you can make contact with that person and open up a conversation about whether they would be well suited to supervise your research. This person will expect you to have done a bit of homework before reaching out to them, in the very least enough to know about their specialisations and perhaps having read a few things they've written on the subject. You don't need to cite our work back to us, but please don't make an approach until you're confident about that person being at least interested in your subject and experienced in supervising work on it on the basis of a few hours invested in reading their work. This is a person you will spend at least three years with, working quite closely together, so this is a reasonable expectation.
- It is generally considered impolite to send an inquiry concurrently to several different members of staff in the same department without letting them know you are doing so. Do your homework first, identify that specific person, and have a conversation with them (or 2-3 of them at different universities).
- In some cases, I am happy to make suggestions as to whom else it might be relevant to approach as a prospective supervisor, especially if you have not had the benefit of the forms of privilege which make these social networks perspicuous. However, it is generally considered ungracious to ask us to do reconaissance for you, especially if you have already asked us to consider a research proposal which isn't relevant to our various forms of expertise. If in any doubt, don't hesitate to ask.


### Step 2. Formulate a research proposal

Given the accelerated nature of the British PhD, a prospective supervisor will expect you to have some sense of the kind of research you want to conduct, be able to communicate this interest coherently and also demonstrate some awareness of the existing sub-field of research.

You can demonstrate this primarily by writing a research proposal. Expectations on these vary, but in my case, I'd prefer to receive a document that is between 1-2 pages (single-spaced in 12 point times new roman font). 

Your research proposal should do the following:

1. Explain why you’ve chosen this particular topic (this can and should be couched in personal narrative)
2. Explain why this research might be significant or novel in light of relevant extant scholarly literature (and by relevant, I generally mean scholarship that has been conducted in the past 20 years in scholarly outlets, so not the BBC and not journal articles from 1950)
3. Explain which streams of existing scholarship you might be interacting with (e.g. "these three scholars (citation 1, citation 2, citation 3) have suggested x, and I'd like to further test their claims...")

All of this gets towards explaining also how this project might be viable to undertake within the space of a 3-year full time doctoral programme

In order to write this, you will need to conduct some research. If you do not have access to a local University library or a public library, there is still quite a lot online, do some work scanning google scholar and google books to get started. If you genuinely believe that you are unable to access resources which would help you to complete a research proposal, let me know in your initial correspondence and we'll see about addressing that challenge together.

It's possible you've already written a paper as a part of your Masters degree which helped you to stumble on your topic. If this is the case, please do go on to reconstitute your thinking in the form of a research proposal, rather than simply sending your paper along. You are welcome to include writing samples along with the research proposal if you have longer-form work you'd like to reference or share with us as part of your application, but please do the work of distilling your research proposal before sending it along. I have spent time reading proposals that are 20-30 pages and I have rarely found that they communicate details about a programme of research that couldn't be summarised well in 2 pages.

You can demonstrate that you have done this kind of research work by including some of the following features in your proposal:

1. Summarising trends in existing literature, with citations to the specific studies you are drawing on in your summary (no vague hand waving please)
2. Briefly citing seminal works in the field, explaining how you plan to build on or refute specific premises therein (this is the one exception to my comment above about literature needing to be recent)
3. Briefly citing or summarising contemporary work in your chosen sub-field. I take "contemporary" to mean research which has been conducted in the last 20 years and will expect you to mention at least 2-3 studies which have been written in the last 5 years.

Important note: in this research proposal you should locate yourself in some specific sub-field of ethics, theology, or religious studies, so not "Christian theology" or "sociology" but something more like "pentecostal Christian eco-theology" or "studies of religious environmental activists in Europe".

This proposal should not be perfect, but it should be polished. I'll notice if there are typographical errors.

No one will expect you to conduct the exact study that you propose in this document - it is intended to demonstrate that you *can* formulate and communicate a research project, not that you have already done one. However, it should have some anchoring in work you have done and might be expected to do in the future based on your skills, experience, and training to date. So not wildly aspirational, please. If you decide to matriculate for PhD study with me, in our first supervision we'll use your research proposal as a leaping-off point to plan out 3-6 months of exploratory inquiry and writing.

There are some more specific expectations regarding different genres of research proposal you may want to be aware of:

- If you are planning on conducting research in a *non-English language* (e.g. Farsi, Hebrew, French, Greek, Latin, etc.), I will expect you to have developed some level of initial competency before starting your PhD. We do have excellent resources for PhD candidates wanting to delve more deeply into modern languages at the UOB, but this works best when strengthening some initial experience.
- If you want to run a research project that is a *comparative study*, particularly if this is comparing separate religious traditions (and not just denominations), you should have some initial previous research experience with *all* of the contexts you want to compare either engaging with gathering and analysing empirical data, or interacting with recent and nuanced scholarship on those contexts. When you have attained this level of experience, it's likely you will have a growing awareness of how challenging it is to compare more than 2 vectors (e.g. 3, 4, or more). Conducting comparative analysis at this level generally the experience of a senior researcher, a number of years post-PhD. So if your project has a large number, you might consider narrowing it in the proposal to just two specific contexts and making your account of those contexts and points of comparison more forensic.
- If your project engages with *data collection*, I will be wary of proposals that aim to do this via 2 or more avenues, e.g. ethnographic fieldwork, interviews, focus groups and surveys. It's generally the case in social scientific disciplines that a PhD project will engage with a single field of data and I think this level of self-discipline is probably wise. Having conducted mixed methods research myself I it has been my experience that the process of comparing different fields of data is very challenging and requires advanced research experience, potentially an entire team of researchers or several decades of fieldwork experience. You should have some prior experience with social science methodologies or training. If you've not done this kind of work previously, and would like to do so in the context of an advanced degree, I'll recommend that you "test the waters" with an MRes degree first. Already having completed an MA or PhD in a non-social-science subject doesn't count, as this won't have included the kind of training that will prepare you to do this kind of work.
- If your project aims to *cut-across humanities and social sciences* (and I am very enthusiastic about this kind of research), e.g. as in "field philosophy" which aims to blend constructive philosophical theology alongside ethnographic fieldwork, I'll expect you to have some previous experience with both fields you want to combine.
- If your project has an *impact focus*, through *action research*, e.g. changing a particular field of practice, or shaping public engagement with a particular social issue you're passionate about, I'll want to know why you think that PhD research will provide the right kind of impact for the context you want to impact. When you reflect on this, please bear in mind that a PhD thesis is a very weird creature, written ultimately for 2 examiners who will have specific genre expectations for your project, which will likely limit the forms of practical engagement you can pursue. They will also expect very high levels of nuance and contextual analysis which will, again, limit the amount of time and space you have left for pursuing change. I'm not saying this kind of project is inadvisable. I've supervised several, and was delighted to be a part of impactful research. My key point here is that it's hard work to fit into a PhD and you'll need to bring quite circumscribed aspirations to that research, e.g. changing things within this one organisastion in x and y small ways. A great way to address this is to review [recent previous examples of action-research theses](https://etheses.bham.ac.uk/cgi/facet/simple2?q=%22action+research%22&q=Search&_action_search=Search&_order=bytitle&basic_srchtype=ALL&_satisfyall=ALL&limit=5) in the discipline and subject you are aiming towards. It's also worth noting that I have ongoing research collaborations with activists and practictioners, so it's possible I'd nonetheless be up for collaborating on a project which you've concluded lies outside the remit of a PhD. Please do also get in touch if you'd be interested in paid coaching or consultancy, which can be considerably less expensive than three years of PhD tuition and subject to artificial constraints.
- If your project aims to interact with personal experience, in the form of an extended *reflection on practice or personal narrative* (e.g. auto-ethnography), I will recommend that you consider applying towards our [Doctorate in Practical Theology](https://www.birmingham.ac.uk/postgraduate/courses/research/thr/practical-theology-doctorate). This programme is purpose-built for this kind of practice-engaged reflection, providing cohort-based support and a thesis submission template that is particular to practice-based research. I've been active in supporting and supervising successful projects under this programme before and I think it's a great model.

Have a look at previous PhD theses which have been successful, you can find [examples which have been completed at Birmingham here](https://etheses.bham.ac.uk/). Generally, the first chapter of a thesis will represent a revised version of the research proposal. If you can't find anything that remotely resembles the kind of project you want to do, it's likely that you need to be a bit more creative with your search keywords, or perhaps an indication that the project you're considering will be more challenging that you anticipate. To give one example, at the time of this writing, there are more than 500 theses with the keyword "action research". You can also zoom out a bit and review theses written in the UK using the [British Library ethos database](http://ethos.bl.uk/Home.do) (do note that the British Library was subject to a massive cyber attack a year ago and [services are still recovering](https://blogs.bl.uk/living-knowledge/2024/08/restoring-our-services-30-august-update.html) so you may not be able to access theses stored there). You should review PhD theses conducted in other countries outside the UK, but bear in mind that the process of examination is quite different, so the genre of writing may not be as useful for you in setting expectations and making plans.

Please note: I know that the "research proposal" format is a peculiar white anglophone-culture device. So, it is important to note that I will set aside this expectation if you have personal reason not to follow convention. In the past, I have welcomed proposals in longer-form personal narrative, or in non-propositional forms, e.g. forms of artistic portfolio or practice. I also welcome more open-ended proposals which aim to pursue action research, auto-ethnography or participatory inquiry (though be aware that I am aware of the methodological literature on all of these modes of inquiry).


### Step 3. Make an initial inquiry

Having done some reconaissance, conducted some research and crytallised your intellectual desires into a research proposal, it's time to make contact.

You should do this via email, with a brief note of introduction, a summary of your topic in 2-3 sentences and some indications of why you think my background would make me a suitable supervisor for the topic you are pursuing. A bit of biographical detail is also nice in helping me to know about why you've decided to do PhD work. It is expected that your actual programme of research will potentially be quite different from what you propose in our initial conversations. It is likely that I will suggest revisions once we begin supervision. This email is meant to help me to connect with your interests, assess whether I'd be a viable supervisor for your work and whether your project could be a viable PhD programme. Sometimes people feel ready to send along a fully worked up research proposal and writing sample at this stage. In other cases, you may want to test the waters with an idea first. I'm fine with either approach.

I get a large number of inquiries each year, so I have to be careful about how much time I invest in feedback on proposals and project ideas. With this in mind, I prefer to save detailed feedback for late-stage proposals where my advice can be most useful. Remember, the point of this interaction is to demonstrate that you have sufficient preparation and training to begin a very advanced and accelerated programme of independent research. I'll aim to provide a few suggestions for revision and will expect a prospective candidate to conduct some research and produce something that is substantially different without a lot of specific guidance on my part. Please don't expect me to review a number of only slightly changed drafts. I'd love to be able to provide this kind of support, but need to reserve that kind of energy for my matriculated PhD cohort and undergraduate students I'm involved in teaching week-to-week.

Once you've sent me a formal written research proposal I may make suggestions for revision and ask you to return a revised proposal (no more than two drafts, and more likely just one, depending on how things come together). Once we've reached a final form for your proposal and I've had time to review it (bear in mind this can be as long as a few weeks at some busy points in the academic year) and if things seem to fit, I'll invite you to do an interview by phone or videoconference so we can chat about the details of your proposal and also so that I can answer questions you might have. You are welcome to choose not to make revisions to your proposal. If I make suggesions, my intent here is to help you to refine your research in order to make it more viable, with the expectation that this might strengthen your application to any number of universities. It's worth noting that this process isn’t any guarantee of a particular result with regards to your application for admission to the programme, but rather is meant to serve as part of the broader process of application. Based on the proposal and the interview, I'll make a reecommendation regarding your application which will go to our Head of Postgraduate studies for review. You'll get a formal response from our admissions team, usually within a month. Please let me know if there are specific time-pressures for your application up front and I'll try my best to make sure we can work within those constraints.